Implementation of the varu64 format in rust.
Enums
Everything that can go wrong when decoding a varu64.
Functions
Decode a
u64 from the input buffer, returning the number and the remaining bytes.Encodes
n into the output buffer, returning how many bytes have been written.Return how many bytes the encoding of
n will take up.